@@ -2,11 +2,11 @@
 **  Copyright (c) 2005-2007 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: util.c,v 1.49 2007/09/07 00:28:57 msk Exp $
+**  $Id: util.c,v 1.55 2007/09/28 17:26:04 msk Exp $
 */
 
 #ifndef lint
-static char util_c_id[] = "@(#)$Id: util.c,v 1.49 2007/09/07 00:28:57 msk Exp $";
+static char util_c_id[] = "@(#)$Id: util.c,v 1.55 2007/09/28 17:26:04 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -16,6 +16,7 @@ static char util_c_id[] = "@(#)$Id: util.c,v 1.49 2007/09/07 00:28:57 msk Exp $"
 #include <sys/resource.h>
 #include <sys/file.h>
 #include <netinet/in.h>
+#include <sys/un.h>
 #include <arpa/inet.h>
 #include <assert.h>
 #include <syslog.h>
@@ -92,10 +93,6 @@ static char *optlist[] =
 	"_FFR_SELECT_SIGN_HEADERS",
 #endif /* _FFR_SELECT_SIGN_HEADERS */
 
-#if _FFR_SET_REPLY
-	"_FFR_SET_REPLY",
-#endif /* _FFR_SET_REPLY */
-
 #if _FFR_STATS
 	"_FFR_STATS",
 #endif /* _FFR_STATS */
@@ -862,3 +859,87 @@ dkimf_hostlist(char *host, char **list)
 	/* not found */
 	return FALSE;
 }
+
+/*
+**  DKIMF_SOCKET_CLEANUP -- try to clean up the socket
+**
+**  Parameters:
+**  	sockspec -- socket specification
+**
+**  Return value:
+**  	0 -- nothing to cleanup or cleanup successful
+**  	other -- an error code (a la errno)
+*/
+
+int
+dkimf_socket_cleanup(char *sockspec)
+{
+	int s;
+	char *colon;
+	struct sockaddr_un sock;
+
+	assert(sockspec != NULL);
+
+	/* we only care about "local" or "unix" sockets */
+	if (sockspec[0] != '/' &&
+	    strncasecmp(sockspec, "local:", 6) != 0 &&
+	    strncasecmp(sockspec, "unix:", 5) != 0)
+		return 0;
+
+	/* find the filename */
+	colon = strchr(sockspec, ':');
+	if (colon == NULL || strlen(colon + 1) == 0)
+		return EINVAL;
+
+	/* get a socket */
+	s = socket(PF_UNIX, SOCK_STREAM, 0);
+	if (s == -1)
+		return errno;
+
+	/* set up a connection */
+	memset(&sock, '\0', sizeof sock);
+#ifdef BSD
+	sock.sun_len = sizeof sock;
+#endif /* BSD */
+	sock.sun_family = PF_UNIX;
+	sm_strlcpy(sock.sun_path, colon + 1, sizeof sock.sun_path);
+
+	/* try to connect */
+	if (connect(s, (struct sockaddr *) &sock, (socklen_t) sizeof sock) != 0)
+	{
+		/* if ECONNREFUSED, try to unlink */
+		if (errno == ECONNREFUSED)
+		{
+			close(s);
+
+			if (unlink(sock.sun_path) == 0)
+				return 0;
+			else
+				return errno;
+		}
+
+		/* if ENOENT, the socket's not there */
+		else if (errno == ENOENT)
+		{
+			close(s);
+
+			return 0;
+		}
+
+		/* something else happened */
+		else
+		{
+			int saveerr;
+
+			saveerr = errno;
+
+			close(s);
+
+			return saveerr;
+		}
+	}
+
+	/* connection apparently succeeded */
+	close(s);
+	return EADDRINUSE;
+}
