@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_setup_c_id[] = "@(#)$Id: t-setup.c,v 1.5 2007/05/11 01:15:44 msk Exp $";
+static char t_setup_c_id[] = "@(#)$Id: t-setup.c,v 1.6 2007/09/17 16:37:22 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -53,6 +53,9 @@ main(int argc, char **argv)
 	}
 	fprintf(f, "\n");
 
+	fprintf(f, "%s.%s.%s ", DKIM_DNSPOLICYNAME, DKIM_DNSKEYNAME, DOMAIN2);
+	fprintf(f, "dkim=all; r=%s\n", REPLYADDRESS);
+
 	fclose(f);
 
 	return 0;
