@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char util_c_id[] = "@(#)$Id: util.c,v 1.11 2007/05/12 14:41:39 msk Exp $";
+static char util_c_id[] = "@(#)$Id: util.c,v 1.13 2007/08/15 01:14:23 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -51,46 +51,6 @@ dkim_collapse(u_char *str)
 	*r = '\0';
 }
 
-/*
-**  DKIM_LOWERCASE -- convert a string to lowercase
-**
-**  Parameters:
-**  	str -- string to process
-**
-**  Return value:
-**  	None.
-*/
-
-void
-dkim_lowercase(u_char *str)
-{
-	u_char *p;
-
-	assert(str != NULL);
-
-	for (p = str; *p != '\0'; p++)
-	{
-		if (isascii(*p) && isupper(*p))
-			*p = tolower(*p);
-	}
-}
-
-/*
-**  DKIM_ISWSP -- return true iff a character is some kind of whitespace
-**
-**  Parameters:
-**  	c -- character being examined
-**
-**  Return value:
-**  	TRUE iff 'c' refers to something considered whitespace.
-*/
-
-bool
-dkim_iswsp(u_int c)
-{
-	return (isascii(c) && isspace(c));
-}
-
 /*
 **  DKIM_ISLWSP -- return true iff a character is some kind of linear
 **                 whitespace
@@ -318,7 +278,6 @@ dkim_hexchar(int c)
 
 	  default:
 		assert(0);
+		return -1;
 	}
-
-	/* NOTREACHED */
 }
